# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`ipmi`](#ipmi): Manages OpenIPMI

#### Private Classes

* `ipmi::config`
* `ipmi::install`
* `ipmi::service::ipmi`
* `ipmi::service::ipmievd`

### Defined types

* [`ipmi::network`](#ipminetwork): Manage BMC network configuration
* [`ipmi::snmp`](#ipmisnmp): Manage SNMP community strings
* [`ipmi::user`](#ipmiuser): Manage BMC users

## Classes

### <a name="ipmi"></a>`ipmi`

Manages OpenIPMI

#### Parameters

The following parameters are available in the `ipmi` class:

* [`packages`](#packages)
* [`config_file`](#config_file)
* [`service_name`](#service_name)
* [`service_ensure`](#service_ensure)
* [`ipmievd_service_name`](#ipmievd_service_name)
* [`ipmievd_service_ensure`](#ipmievd_service_ensure)
* [`watchdog`](#watchdog)
* [`snmps`](#snmps)
* [`users`](#users)
* [`networks`](#networks)

##### <a name="packages"></a>`packages`

Data type: `Array[String]`

List of packages to install.

##### <a name="config_file"></a>`config_file`

Data type: `Stdlib::Absolutepath`

Absolute path to the ipmi service config file.

##### <a name="service_name"></a>`service_name`

Data type: `String`

Name of IPMI service.

##### <a name="service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`

Controls the state of the `ipmi` service. Possible values: `running`, `stopped`

##### <a name="ipmievd_service_name"></a>`ipmievd_service_name`

Data type: `String`

Name of ipmievd service.

##### <a name="ipmievd_service_ensure"></a>`ipmievd_service_ensure`

Data type: `Stdlib::Ensure::Service`

Controls the state of the `ipmievd` service. Possible values: `running`, `stopped`

##### <a name="watchdog"></a>`watchdog`

Data type: `Boolean`

Controls whether the IPMI watchdog is enabled.

##### <a name="snmps"></a>`snmps`

Data type: `Optional[Hash]`

`ipmi::snmp` resources to create.

##### <a name="users"></a>`users`

Data type: `Optional[Hash]`

`ipmi::user` resources to create.

##### <a name="networks"></a>`networks`

Data type: `Optional[Hash]`

`ipmi::network` resources to create.

## Defined types

### <a name="ipminetwork"></a>`ipmi::network`

Manage BMC network configuration

#### Parameters

The following parameters are available in the `ipmi::network` defined type:

* [`ip`](#ip)
* [`netmask`](#netmask)
* [`gateway`](#gateway)
* [`type`](#type)
* [`lan_channel`](#lan_channel)

##### <a name="ip"></a>`ip`

Data type: `Stdlib::IP::Address`

Controls the IP of the IPMI network.

Default value: `'0.0.0.0'`

##### <a name="netmask"></a>`netmask`

Data type: `Stdlib::IP::Address`

Controls the subnet mask of the IPMI network.

Default value: `'255.255.255.0'`

##### <a name="gateway"></a>`gateway`

Data type: `Stdlib::IP::Address`

Controls the gateway of the IPMI network.

Default value: `'0.0.0.0'`

##### <a name="type"></a>`type`

Data type: `Enum['dhcp', 'static']`

Controls the if IP will be from DHCP or Static.

Default value: `'dhcp'`

##### <a name="lan_channel"></a>`lan_channel`

Data type: `Integer`

Controls the lan channel of the IPMI network to be configured.

Default value: `1`

### <a name="ipmisnmp"></a>`ipmi::snmp`

Manage SNMP community strings

#### Parameters

The following parameters are available in the `ipmi::snmp` defined type:

* [`snmp`](#snmp)
* [`lan_channel`](#lan_channel)

##### <a name="snmp"></a>`snmp`

Data type: `String`

Controls the snmp string of the IPMI network interface.

Default value: `'public'`

##### <a name="lan_channel"></a>`lan_channel`

Data type: `Integer`

Controls the lan channel of the IPMI network on which snmp is to be configured.

Default value: `1`

### <a name="ipmiuser"></a>`ipmi::user`

Manage BMC users

#### Parameters

The following parameters are available in the `ipmi::user` defined type:

* [`user`](#user)
* [`password`](#password)
* [`priv`](#priv)
* [`user_id`](#user_id)

##### <a name="user"></a>`user`

Data type: `String`

Controls the username of the user to be created.

Default value: `'root'`

##### <a name="password"></a>`password`

Data type: `String`

Controls the password of the user to be created.

##### <a name="priv"></a>`priv`

Data type: `Integer`

Possible values:
`4` - ADMINISTRATOR,
`3` - OPERATOR,
`2` - USER,
`1` - CALLBACK

Controls the rights of the user to be created.

Default value: `4`

##### <a name="user_id"></a>`user_id`

Data type: `Integer`

The user id of the user to be created. Should be unique from existing users. On
SuperMicro IPMI, user id 2 is reserved for the ADMIN user.

Default value: `3`

